package main

import (
	"log"
	"os"

	"git.pbiernat.dev/egommerce/go-api-pkg/config"

	cnf "git.pbiernat.dev/egommerce/basket-service/internal/config"
	"git.pbiernat.dev/egommerce/basket-service/internal/worker"
)

func main() {
	if config.ErrLoadingEnvs != nil {
		log.Fatalln("Error loading .env file.")
	}

	c := cnf.NewConfig("basket-worker")
	wrk := worker.New(
		c,
		worker.WithCache(c),
		worker.WithDatabase(c),
		worker.WithEventbus(c),
		worker.WithLogger(c),
		worker.WithRegistry(c),
	)

	while := make(chan struct{})
	err := wrk.Start(while)
	<-while

	if err != nil {
		log.Fatalf("Failed to start worker. Reason: %v\n", err)
		os.Exit(1)
	}

	os.Exit(0)
}
