package worker

import (
	"git.pbiernat.dev/egommerce/basket-service/internal/service"
	"git.pbiernat.dev/egommerce/basket-service/internal/ui"
)

var (
	AddProductToBasket      = "event.ProductAddedToBasket"
	RemoveProductFromBasket = "event.ProductRemovedFromBasket"
)

type Command interface {
	run(CommandData) (bool, any)
}

type CommandData map[string]interface{}

type CommandRunner struct {
	cmd Command
}

func NewCommandRunner(cmd string, srvc *service.BasketService) *CommandRunner {
	rnr := &CommandRunner{}
	rnr.cmd = getCommand(cmd, srvc)

	return rnr
}

func getCommand(cmd string, srvc *service.BasketService) Command {
	// fmt.Printf("getCommand: %v\n", cmd)
	var c Command

	switch cmd { // FIXME
	case "AddProductToBasket":
		c = &AddProductToBasketCommand{srvc}
	case "RemoveProductFromBasket":
		c = &RemoveProductFromBasketCommand{srvc}
	}

	return c
}

func (r *CommandRunner) run(data CommandData) (bool, any) {
	return r.cmd.run(data)
}

type AddProductToBasketCommand struct {
	srvc *service.BasketService // FIXME: Remove service dep
}

func (c *AddProductToBasketCommand) run(data CommandData) (bool, any) { // FIXME: Move run func to WorkerPool
	reqID := data["request_id"].(string)           // FIXME Check input params!
	productID := int(data["product_id"].(float64)) // FIXME Check input params!
	basketID := data["basket_id"].(string)         // FIXME Check input params!
	qty := int(data["quantity"].(float64))         // FIXME Check input params!

	basket, err := ui.AddProductToBasket(c.srvc, productID, qty, basketID, reqID)

	return err == nil, basket
}

type RemoveProductFromBasketCommand struct {
	srvc *service.BasketService // FIXME: Remove service dep
}

func (c *RemoveProductFromBasketCommand) run(data CommandData) (bool, any) { // FIXME: Move run func to WorkerPool
	reqID := data["request_id"].(string)           // FIXME Check input params!
	productID := int(data["product_id"].(float64)) // FIXME Check input params!
	basketID := data["basket_id"].(string)         // FIXME Check input params!
	qty := int(data["quantity"].(float64))         // FIXME Check input params!

	basket, err := ui.RemoveProductFromBasket(c.srvc, productID, qty, basketID, reqID)

	return err == nil, basket
}
